VertexSelector

Enum VertexSelector 

pub enum VertexSelector<'a> {
    All,
    None,
    Single(igraph_int_t),
    List(Cow<'a, [igraph_int_t]>),
    Range(igraph_int_t, igraph_int_t),
    Adjacent {
        vertex: igraph_int_t,
        mode: NeighborMode,
    },
    NonAdjacent {
        vertex: igraph_int_t,
        mode: NeighborMode,
    },
}
A set of vertices, see the module docs.

Variants



All

All vertices, in increasing id order.



None

No vertex.



Single(igraph_int_t)

A single vertex.



List(Cow<'a, [igraph_int_t]>)

The listed vertices, in the given order (duplicates allowed).



Range(igraph_int_t, igraph_int_t)

Vertices with id in start..end; like a Rust range it is empty (and selects nothing, whatever the graph) when start >= end.



Adjacent

Neighbors of a vertex, each listed once, in increasing order (loops and multi-edges are ignored; see Graph::adjacent_vertices for other conventions).

Fields

vertex: igraph_int_t

The center vertex.

mode: NeighborMode

Which neighbors, for directed graphs.



NonAdjacent

Vertices not adjacent to a vertex.

Fields

vertex: igraph_int_t

The center vertex.

mode: NeighborMode

Which neighbors, for directed graphs.

Implementations

Source

impl<'a> VertexSelector<'a>

pub fn adjacent(vertex: igraph_int_t, mode: NeighborMode) -> Self

The neighbors of vertex (shorthand for VertexSelector::Adjacent).

pub fn non_adjacent(vertex: igraph_int_t, mode: NeighborMode) -> Self

The vertices not adjacent to vertex (shorthand for VertexSelector::NonAdjacent).

pub fn into_owned(self) -> VertexSelector<'static>

An owned copy of the selector, not borrowing anything.

Source

impl VertexSelector<'_>

pub fn to_raw(&self) -> Result<RawVs>

Builds the raw igraph selector (igraph_vs_t), for calling raw FFI functions; the safe wrappers of the crate do it for you.

Empty ranges (start >= end) become igraph_vs_none: igraph 1.0.0 and 1.0.1 would reject an empty range starting at vcount and accept a decreasing one with a negative size.

Errors

Only if igraph fails to build the selector (e.g. out of memory); vertex ids are validated when the selector is used.